@@ -1,8 +1,8 @@
 #include <sdsl/io.hpp>
-#include <sdsl/int_vector.hpp>
-#include <sdsl/rrr_vector.hpp>
-#include <sdsl/rank_support_v.hpp>
-#include <sdsl/select_support_mcl.hpp>
+#include <sdsl/bit_vectors.hpp>
+#include <sdsl/rank_support.hpp>
+#include <sdsl/select_support.hpp>
+#include <sdsl/wavelet_trees.hpp>
 #include "common.hpp"
 
 #ifndef SDSL_C_IO_H
