@@ -6,9 +6,10 @@ pub mod int_vector;
 pub mod rank_support_v;
 pub mod rrr_vector;
 pub mod select_support_mcl;
+pub mod wavelet_trees;
 
-pub fn get_all() -> Result<Vec<Box<dyn common::Meta>>> {
-    Ok(vec![
+pub fn get_metas() -> Result<Vec<Box<dyn common::Meta>>> {
+    let mut metas = vec![
         Box::new(int_vector::IntVectorMeta::new()) as Box<dyn common::Meta>,
         Box::new(bit_vector::BitVectorMeta::new()) as Box<dyn common::Meta>,
         Box::new(rrr_vector::RrrVectorMeta::new()) as Box<dyn common::Meta>,
@@ -18,5 +19,7 @@ pub fn get_all() -> Result<Vec<Box<dyn common::Meta>>> {
         Box::new(common::bit_patterns::P1Meta::new()) as Box<dyn common::Meta>,
         Box::new(common::bit_patterns::P10Meta::new()) as Box<dyn common::Meta>,
         Box::new(common::bit_patterns::P01Meta::new()) as Box<dyn common::Meta>,
-    ])
+    ];
+    metas.extend(wavelet_trees::get_metas()?);
+    Ok(metas)
 }
